Assembling Clinical Information for the Bonome Ovarian Data
===========================================================

by Keith A. Baggerly

## 1 Executive Summary

### 1.1 Introduction

We want to produce an RData file with the
clinical information for the
ovarian cancer samples
profiled by [Bonome et al.](#bonome08)
on U133A arrays.

### 1.2 Methods

We acquired clinical annotation from
the Gene Expression Omnibus (GEO) pages descending
from the main page GSE26712,
[http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE26712](http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE26712),
on Sep 12, 2012.
This includes the GEO GSM id for each sample, the sample
ID, Surgery Outcome (DOD, AWD, NED), and Survival in Years.

A csv file of this annotation is stored in RawData
as bonomeClinical.csv.

We load the clinical information into a data frame, and
construct an R "Surv"" object for overall survival.

### 1.3 Results

We save bonomeClinical and
bonomeOSYrs
to the RData file "bonomeClinical.RData".

## 2 Libraries

We first load the libraries we will use
in this report.


```r

library(survival)
```

```
## Loading required package: splines
```


## 3 Loading the Data

Here we simply load the table of clinical information.



```r

bonomeClinical <- read.table(file.path("RawData", "Bonome", "Clinical", "bonomeClinical.csv"), 
    header = TRUE, sep = ",")
dim(bonomeClinical)
```

```
## [1] 195   5
```

```r
bonomeClinical[1:3, ]
```

```
##      GEO.ID SampleID SurgeryOutcome Status SurvivalYears
## 1 GSM657519 HOSE2237                                  NA
## 2 GSM657520 HOSE2008                                  NA
## 3 GSM657521 HOSE2061                                  NA
```

```r

rownames(bonomeClinical) <- as.character(bonomeClinical[, "SampleID"])
```


## 4 Defining Overall Survival

Next, we define an R "Surv"" object for overall survival (OS)
We begin by looking at
the recorded values for patient status.


```r

table(bonomeClinical[, "Status"])
```

```
## 
##     AWD DOD NED 
##  10  24 129  32
```


Here, AWD = Alive with Disease, DOD = Dead of Disease,
and NED = Alive with no Evidence of Disease.

Next, we define an indicator vectors for OS.


```r

bonomeOSStatus <- rep(NA, nrow(bonomeClinical))
bonomeOSStatus[bonomeClinical[, "Status"] == "AWD"] <- "Censored"
bonomeOSStatus[bonomeClinical[, "Status"] == "DOD"] <- "Uncensored"
bonomeOSStatus[bonomeClinical[, "Status"] == "NED"] <- "Censored"
table(bonomeOSStatus)
```

```
## bonomeOSStatus
##   Censored Uncensored 
##         56        129
```


Now we create the Surv object.


```r

bonomeOSYrs <- Surv(bonomeClinical[, "SurvivalYears"], bonomeOSStatus == "Uncensored")
rownames(bonomeOSYrs) <- rownames(bonomeClinical)
```


## 5 Saving RData

Now we save the relevant information to an RData object.


```r

save(bonomeClinical, bonomeOSYrs, file = file.path("RDataObjects", "bonomeClinical.RData"))
```



## 6 Appendix

### 6.1 File Location


```r

getwd()
```

```
## [1] "\\\\mdadqsfs02/workspace/kabagg/RDPaper/Webpage/ResidualDisease"
```


### 6.2 SessionInfo


```r

sessionInfo()
```

```
## R version 2.15.3 (2013-03-01)
## Platform: x86_64-w64-mingw32/x64 (64-bit)
## 
## locale:
## [1] LC_COLLATE=English_United States.1252 
## [2] LC_CTYPE=English_United States.1252   
## [3] LC_MONETARY=English_United States.1252
## [4] LC_NUMERIC=C                          
## [5] LC_TIME=English_United States.1252    
## 
## attached base packages:
## [1] splines   stats     graphics  grDevices utils     datasets  methods  
## [8] base     
## 
## other attached packages:
## [1] survival_2.37-4 knitr_1.2      
## 
## loaded via a namespace (and not attached):
## [1] digest_0.6.3   evaluate_0.4.3 formatR_0.7    stringr_0.6.2 
## [5] tools_2.15.3
```


## 7 References

> <p id="bonome08">[1] 
  Bonome T, Levine DA, Shih J, Randonovich M, Pise-Masison CA,
  Bogomolniy F, Ozbun L, Brady J, Barrett JC, Boyd J, Birrer MJ.
  A gene signature predicting for survival in suboptimally debulked
  patients with ovarian cancer.
  <em>Cancer Res</em>, <b>68(13)</b>:5478-86, 2008.</p>
